from subprocess import call
import os

class SSHController:
    def __init__(self, keypair_dir, keypair_name, keypair_extension, host):
        self.keypair = '%s/%s.%s' % (keypair_dir, keypair_name, keypair_extension)
        self.host = host
        self.alternate_usernames = ['centos', 'ec2-user', 'ubuntu', 'admin', 'bitnami', 'root']
        self.devnull = open(os.devnull, 'w')

    def ssh(self, command=''):
        return_code = self._ssh(command)
        if return_code == 255:
            for username in self.alternate_usernames:
                return_code = self._ssh(command, username)
                if return_code != 255:
                    return



    def _ssh(self, command, username=None):
        ssh_cmd = "ssh -q -i %s " % self.keypair
        if username:
            ssh_cmd += "%s@" % username
        ssh_cmd += "%s%s" % (self.host, command)

        return call(ssh_cmd, shell=True)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import click
from ec2.controller import EC2Controller
from ssh.controller import SSHController
from essh.exceptions import ESSHException

@click.command(context_settings=dict(ignore_unknown_options=True,))
@click.option('--profile', '-p', help='AWS credentials profile (i.e. ~/.aws/credentials)')
@click.option('--zone', '-z', help='Filter hosts by availability zone specified (i.e. us-east-1a)')
@click.option('--keypair-dir', default="~/.ssh", help='Directory where keypair files are located')
@click.option('--keypair-extension', default="pem", help='File extension for keypari files')
@click.argument('target')
@click.argument('command', nargs=-1, type=click.UNPROCESSED)
def cli(profile, zone, keypair_dir, keypair_extension, target, command):
    cmd = " ". join(command)
    if len(cmd) > 0:
        cmd = " " + cmd

    ec2_controller = EC2Controller(profile, zone)
    try:
        instance = ec2_controller.find(target)
        SSHController(keypair_dir, instance.keypair, keypair_extension, instance.private_ip).ssh(cmd)
    except ESSHException as ex:
        print(ex.message)

if __name__ == '__main__':
    cli()



from essh.ec2.api import EC2
from essh.exceptions import ESSHException
import re

class EC2Controller:
    def __init__(self, profile_name, zone):
        self.instance_id_regex = re.compile('^i-')
        self.ip_regex = re.compile('^[0-9]+\.[0-9]+\.[0-9]+\.[0-9]+')
        self.api = EC2(profile_name=profile_name, zone=zone)

    def find(self, target):
        if re.search(self.instance_id_regex, target) is not None:
            return self.api.find_by_id(target)
        elif re.search(self.ip_regex, target) is not None:
            return self.api.find_by_ip(target)
        else:
            return self.api.find_by_name(target)



import os
from setuptools import setup, find_packages
import warnings

setup(
    name='essh',
    version='0.4.0',
    packages=find_packages(),
    include_package_data=True,
    install_requires=[
        'click>=6.6',
        'boto3>=1.4.4',
        'retrying>=1.3.3'
    ],
    entry_points={
        "console_scripts": [
            "essh=essh.cli:cli",
        ]
    },
    namespace_packages = ['essh'],
    author="Patrick Cullen",
    author_email="patrickbcullen@gmail.com",
    url="https://github.com/patrickbcullen/essh",
    download_url = "https://github.com/patrickbcullen/essh/tarball/v0.4.0",
    keywords = ['ssh', 'ec2', 'aws'],
    classifiers = []
)
